Simple tests
-------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/waveform_sine_simpletest.py
    :caption: examples/waveform_sine_simpletest.py
    :linenos:

.. literalinclude:: ../examples/waveform_square_simpletest.py
    :caption: examples/waveform_square_simpletest.py
    :linenos:
